from typing import Any, Dict, List

TransformElementType = Dict[str, Any]
TransformBatchType = Dict[str, List[Any]]
FeatureType = Any
Features = Dict[str, FeatureType]
